# Sync for Commerce

Embedded accounting integrations for POS and eCommerce platforms.

<!-- Start SDK Installation -->
## SDK Installation

```bash
pip install codat-sync-for-commerce
```
<!-- End SDK Installation -->

## SDK Example Usage
<!-- Start SDK Example Usage -->
```python
import codatsynccommerce
from codatsynccommerce.models import shared

s = codatsynccommerce.CodatSyncCommerce(
    security=shared.Security(
        auth_header="YOUR_API_KEY_HERE",
    ),
)


req = shared.CreateCompany(
    name="Bob's Burgers",
)

res = s.company_management.create_company(req)

if res.company is not None:
    # handle response
```
<!-- End SDK Example Usage -->

<!-- Start SDK Available Operations -->
## Available Resources and Operations


### [company_management](docs/companymanagement/README.md)

* [create_company](docs/companymanagement/README.md#create_company) - Create Sync for Commerce company
* [create_connection](docs/companymanagement/README.md#create_connection) - Create connection
* [list_companies](docs/companymanagement/README.md#list_companies) - List companies
* [list_connections](docs/companymanagement/README.md#list_connections) - List data connections
* [update_connection](docs/companymanagement/README.md#update_connection) - Update data connection

### [configuration](docs/configuration/README.md)

* [get_configuration](docs/configuration/README.md#get_configuration) - Retrieve config preferences set for a company.
* [get_sync_status](docs/configuration/README.md#get_sync_status) - Get status for a company's syncs
* [set_configuration](docs/configuration/README.md#set_configuration) - Create or update configuration.

### [integrations](docs/integrations/README.md)

* [get_integration_branding](docs/integrations/README.md#get_integration_branding) - Get branding for an integration
* [list_integrations](docs/integrations/README.md#list_integrations) - List information on Codat's supported integrations

### [sync](docs/sync/README.md)

* [request_sync](docs/sync/README.md#request_sync) - Run a Commerce sync from the last successful sync
* [request_sync_for_date_range](docs/sync/README.md#request_sync_for_date_range) - Run a Commerce sync from a given date range

### [sync_flow_preferences](docs/syncflowpreferences/README.md)

* [get_config_text_sync_flow](docs/syncflowpreferences/README.md#get_config_text_sync_flow) - Retrieve preferences for text fields on Sync Flow
* [get_sync_flow_url](docs/syncflowpreferences/README.md#get_sync_flow_url) - Retrieve sync flow url
* [get_visible_accounts](docs/syncflowpreferences/README.md#get_visible_accounts) - List visible accounts
* [update_config_text_sync_flow](docs/syncflowpreferences/README.md#update_config_text_sync_flow) - Update preferences for text fields on sync flow
* [update_visible_accounts_sync_flow](docs/syncflowpreferences/README.md#update_visible_accounts_sync_flow) - Update the visible accounts on Sync Flow
<!-- End SDK Available Operations -->

### SDK Generated by [Speakeasy](https://docs.speakeasyapi.dev/docs/using-speakeasy/client-sdks)
